# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ...generated_types.types.risk import Risk
from ...generated_types.types.country import Country
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class TradeFilterList(UniversalBaseModel):
    """
    Filter your search on the following attributes.
    """

    buyer_id: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Exact match against the entity_id of the buyer. The buyer is the receiver_of shipments.
    """

    supplier_id: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Exact match against the entity_id of the supplier. The supplier is the shipper_of shipments.
    """

    buyer_name: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Buyers whose name contains the provided string.
    """

    supplier_name: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Shipper whose name contains the provided string.
    """

    buyer_risk: typing.Optional[typing.List[Risk]] = pydantic.Field(default=None)
    """
    Buyer with an exact match for the provided [risk factor](/sayari-library/ontology/risk-factors).
    """

    supplier_risk: typing.Optional[typing.List[Risk]] = pydantic.Field(default=None)
    """
    Shipper with an exact match for the provided [risk factor](/sayari-library/ontology/risk-factors).
    """

    buyer_country: typing.Optional[typing.List[Country]] = pydantic.Field(default=None)
    """
    Buyer with an exact match for the provided [country code](/sayari-library/ontology/enumerated-types#country).
    """

    buyer_city: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Buyer city location
    """

    buyer_state: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Buyer state location
    """

    supplier_country: typing.Optional[typing.List[Country]] = pydantic.Field(default=None)
    """
    Supplier with an exact match for the provided [country code](/sayari-library/ontology/enumerated-types#country).
    """

    supplier_city: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Supplier city location
    """

    supplier_state: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Supplier state location
    """

    departure_country: typing.Optional[typing.List[Country]] = pydantic.Field(default=None)
    """
    Shipment departs from a country with an exact match for the provided [country code](/sayari-library/ontology/enumerated-types#country).
    """

    departure_state: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Shipment departs from a state that contains the provided state name.
    """

    departure_city: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Shipment departs from a city that contains the provided city name.
    """

    arrival_country: typing.Optional[typing.List[Country]] = pydantic.Field(default=None)
    """
    Shipment arrives at a country with an exact match for the provided [country code](/sayari-library/ontology/enumerated-types#country).
    """

    arrival_state: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Shipment arrives at a state that contains the provided state name.
    """

    arrival_city: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Shipment arrives at a city that contains the provided city name.
    """

    hs_code: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The shipment HS code starts with the provided HS code.
    """

    hs_description: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The HS description contains the provided string.
    """

    product_origin: typing.Optional[typing.List[Country]] = pydantic.Field(default=None)
    """
    Product Origin with an exact match for the provided [country code](/sayari-library/ontology/enumerated-types#country).
    """

    supplier_purpose: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The supplier purpose contains the provided string.
    """

    buyer_purpose: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The buyer purpose contains the provided string.
    """

    arrival_date: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The arrival date is within the provided range.
    """

    departure_date: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The departure date is within the provided range.
    """

    shipment_identifier: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The shipment identifier starts with the provided string.
    """

    transit_country: typing.Optional[typing.List[Country]] = pydantic.Field(default=None)
    """
    Countries through which a shipment passes for the provided [country code](/sayari-library/ontology/enumerated-types#country).
    """

    weight: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    The shipment weight is within the provided range.
    """

    sources: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    An exact match for the provided sources.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...base_types.types.paginated_response import PaginatedResponse
from ...shared_types.types.entity_details import EntityDetails
from ...shared_types.types.entity_relationships import EntityRelationships
from ...shared_types.types.relationship_data import RelationshipData
import typing
from .supplier_or_buyer import SupplierOrBuyer
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
from ...core.pydantic_utilities import update_forward_refs


class BuyerSearchResponse(PaginatedResponse):
    """
    OK

    Examples
    --------
    from sayari.base_types import QualifiedCount
    from sayari.shared_types import Identifier, SourceCountInfo
    from sayari.trade import (
        BuyerSearchResponse,
        HsCode,
        SupplierMetadata,
        SupplierOrBuyer,
    )

    BuyerSearchResponse(
        offset=0,
        limit=1,
        size=QualifiedCount(
            count=5974,
            qualifier="eq",
        ),
        next=True,
        data=[
            SupplierOrBuyer(
                id="VRttegVx-TLCsNHKfNe1Cw",
                label='Товариство з обмеженою відповідальністю "ВЕСТ-СПРИНТ"',
                degree=4333,
                entity_url="/v1/entity/VRttegVx-TLCsNHKfNe1Cw",
                pep=False,
                psa_count=0,
                sanctioned=False,
                closed=False,
                translated_label="VOLYN LIMITED LIABILITY COMPANY VOLYN INSTITUTE OF INFORMATION TECHNOLOGIES",
                company_type="АДВОКАТСЬКЕ БЮРО",
                registration_date="Registered 2021-02-02",
                type="company",
                identifiers=[
                    Identifier(
                        value="44102648",
                        type="ukr_edrpou",
                        label="Ukr Edrpou",
                    ),
                    Identifier(
                        value="43994030",
                        type="ukr_edrpou",
                        label="Ukr Edrpou",
                    ),
                    Identifier(
                        value="43913941",
                        type="ukr_edrpou",
                        label="Ukr Edrpou",
                    ),
                    Identifier(
                        value="44154434",
                        type="ukr_edrpou",
                        label="Ukr Edrpou",
                    ),
                    Identifier(
                        value="10019810200000131",
                        type="ukr_reg_num",
                        label="Ukr Reg Num",
                    ),
                ],
                addresses=[
                    ".",
                    "Україна, 43020, Волинська обл., місто Луцьк, вул.Рівненська, будинок 48",
                    "Україна, 43020, Волинська обл., місто Луцьк, вул.Електроапаратна, будинок 17",
                ],
                countries=["UKR"],
                relationship_count={
                    "receiver_of": 4142,
                    "has_beneficial_owner": 73,
                    "has_officer": 65,
                    "has_shareholder": 75,
                    "has_founder": 78,
                    "receives_from": 98,
                    "has_legal_representative": 4,
                },
                trade_count={"sent": 0, "received": 150},
                source_count={
                    "96c06a5a03b61b91324c7e05b3114fb6": SourceCountInfo(
                        count=4142,
                        label="Ukraine Imports & Exports (January 2023 - Present)",
                    ),
                    "d1bce737c158efddbef5048d63aaf124": SourceCountInfo(
                        count=241,
                        label="Ukraine Ministry of Justice Registry of Companies",
                    ),
                },
                risk={},
                user_attribute_count={},
                user_record_count=0,
                user_related_entities_count=0,
                user_relationship_count={},
                related_entities_count=4333,
                attribute_count={
                    "company_type": 6,
                    "name": 77,
                    "business_purpose": 100,
                    "identifier": 70,
                    "additional_information": 56,
                    "country": 2,
                    "contact": 27,
                    "status": 70,
                    "address": 14,
                },
                metadata=SupplierMetadata(
                    latest_shipment_date="2023-10-28",
                    shipments=4142,
                    hs_codes=[
                        HsCode(
                            key="870323",
                            doc_count=1492,
                            value="Vehicles; with only spark-ignition internal combustion reciprocating piston engine, cylinder capacity over 1500 but not over 3000cc",
                            value_simple="Cars & Passenger Vehicles",
                        ),
                        HsCode(
                            key="8703239013",
                            doc_count=1477,
                            value="Vehicles; with only spark-ignition internal combustion reciprocating piston engine, cylinder capacity over 1500 but not over 3000cc",
                            value_simple="Cars & Passenger Vehicles",
                        ),
                        HsCode(
                            key="870332",
                            doc_count=897,
                            value="Vehicles; with only compression-ignition internal combustion piston engine (diesel or semi-diesel), cylinder capacity over 1500 but not over 2500cc",
                            value_simple="Cars & Passenger Vehicles",
                        ),
                        HsCode(
                            key="8703329030",
                            doc_count=830,
                            value="Vehicles; with only compression-ignition internal combustion piston engine (diesel or semi-diesel), cylinder capacity over 1500 but not over 2500cc",
                            value_simple="Cars & Passenger Vehicles",
                        ),
                        HsCode(
                            key="870322",
                            doc_count=551,
                            value="Vehicles; with only spark-ignition internal combustion piston engine, cylinder capacity over 1000 but not over 1500cc",
                            value_simple="Cars & Passenger Vehicles",
                        ),
                    ],
                ),
            )
        ],
    )
    """

    offset: int
    next: bool
    data: typing.List[SupplierOrBuyer]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EntityDetails, BuyerSearchResponse=BuyerSearchResponse)
update_forward_refs(EntityRelationships, BuyerSearchResponse=BuyerSearchResponse)
update_forward_refs(RelationshipData, BuyerSearchResponse=BuyerSearchResponse)



# This file was auto-generated by Fern from our API Definition.

from .types import (
    ShortestPathData,
    ShortestPathResponse,
    TraversalData,
    TraversalPath,
    TraversalRelationshipData,
    TraversalResponse,
)

__all__ = [
    "ShortestPathData",
    "ShortestPathResponse",
    "TraversalData",
    "TraversalPath",
    "TraversalRelationshipData",
    "TraversalResponse",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .match_quality import MatchQuality
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class MatchExplanation(UniversalBaseModel):
    matched: typing.Optional[str] = None
    uploaded: typing.Optional[str] = None
    name_custom_tf_idf_score: typing.Optional[float] = None
    high_quality_match_name: typing.Optional[bool] = None
    is_deletion_recommended: typing.Optional[bool] = None
    n_common_term_matches: typing.Optional[int] = None
    n_uncommon_term_matches: typing.Optional[int] = None
    match_quality: typing.Optional[MatchQuality] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from ...generated_types.types.country import Country
import pydantic
from ...generated_types.types.entities import Entities
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ResolutionResponseFields(UniversalBaseModel):
    name: typing.Optional[typing.List[str]] = None
    identifier: typing.Optional[typing.List[str]] = None
    profile: typing.Optional[str] = None
    country: typing.Optional[typing.List[Country]] = pydantic.Field(default=None)
    """
    Entity country - must be ISO (3166) Trigram i.e., USA. See complete list [here](/sayari-library/ontology/enumerated-types#country)
    """

    address: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of physical addresses associated with the entity.
    """

    date_of_birth: typing.Optional[typing.List[str]] = None
    contact: typing.Optional[typing.List[str]] = None
    type: typing.Optional[typing.List[Entities]] = pydantic.Field(default=None)
    """
    [Entity type](/sayari-library/ontology/entities)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

Tag = typing.Union[
    typing.Literal[
        "pep",
        "state_owned",
        "former_soe",
        "sanctioned",
        "formerly_sanctioned",
        "reputational_risk_terrorism",
        "reputational_risk_organized_crime",
        "reputational_risk_financial_crime",
        "reputational_risk_bribery_and_corruption",
        "reputational_risk_other",
        "reputational_risk_cybercrime",
        "reputational_risk_modern_slavery",
        "regulatory_action",
        "law_enforcement_action",
        "export_controls",
        "forced_labor_xinjiang_contractors",
        "wro_entity",
        "uflpa_entity",
        "sheffield_hallam_university_forced_labor_entity",
        "aspi_uyghur_forced_labor_report_entity",
        "bis_boycott_requester_list",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

Attributes = typing.Union[
    typing.Literal[
        "person_status",
        "country",
        "address",
        "additional_information",
        "company_type",
        "position",
        "weak_identifier",
        "finances",
        "shares",
        "generic",
        "measurement",
        "status",
        "date_of_birth",
        "name",
        "financials",
        "gender",
        "translated_name",
        "risk_intelligence",
        "monetary_value",
        "identifier",
        "contact",
        "business_purpose",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

Risk = typing.Union[
    typing.Literal[
        "sheffield_hallam_university_forced_labor_entity",
        "forced_labor_xinjiang_origin_direct",
        "regulatory_action",
        "forced_labor_uflpa_origin_subtier_product_blueprint",
        "forced_labor_xinjiang_geospatial",
        "eu_high_risk_third",
        "uk_sanctioned",
        "sheffield_hallam_university_useful_resources",
        "exports_to_entity_licensed_with_fsb_rf",
        "owner_of_aspi_forced_labor_entity",
        "sanctioned",
        "reputational_risk_financial_crime",
        "cmic_entity",
        "psa_pep",
        "export_controls",
        "wro_entity",
        "imports_bis_high_priority_items",
        "reputational_risk_bribery_and_corruption",
        "sanctioned_adjacent",
        "psa_export_controls",
        "owner_of_sanctioned_entity",
        "psa_regulatory_action",
        "forced_labor_xinjiang_contractors",
        "uk_50_percent_rule",
        "owned_by_xinjiang_entity",
        "forced_labor_xinjiang_origin_subtier",
        "psa_forced_labor_xinjiang_name",
        "basel_aml",
        "aspi_uyghur_forced_labor_report_entity_adjacent",
        "owned_by_cmic_entity",
        "ofac_sdn",
        "owned_by_bis_meu_entity",
        "forced_labor_aspi_origin_subtier_product_blueprint",
        "owned_by_forced_labor_xinjiang_uflpa",
        "forced_labor_xinjiang_uflpa_adjacent",
        "owned_by_wro_entity",
        "psa_military_civil_fusion",
        "forced_labor_aspi_origin_subtier",
        "former_wro_entity",
        "forced_labor_wro_origin_direct",
        "owned_by_sheffield_hallam_university_reports_forced_labor_entity",
        "eu_sanctioned",
        "aspi_uyghur_forced_labor_report_entity",
        "forced_labor_china_keywords",
        "exports_bis_high_priority_items_critical_components",
        "soe_adjacent",
        "forced_labor_sheffield_hallam_university_reports_origin_subtier_product_blueprint",
        "state_owned",
        "psa_sheffield_hallam_university_forced_labor_entity",
        "export_controls_adjacent",
        "export_to_soe",
        "psa_sanctioned",
        "ofac_50_percent_rule",
        "owner_of_export_controls_entity",
        "forced_labor_sheffield_hallam_university_reports_origin_subtier",
        "meu_list_contractors",
        "forced_labor_xinjiang_cotton_entity",
        "owner_of_forced_labor_xinjiang_uflpa",
        "pep",
        "owned_by_entity_in_export_controls",
        "psa_forced_labor_aspi_uyghur",
        "bis_boycott_requester_list",
        "eu_50_percent_rule",
        "forced_labor_xinjiang_operations",
        "forced_labor_wro_origin_subtier",
        "psa_forced_labor_xinjiang_cotton_entity",
        "reputational_risk_other",
        "export_to_sanctioned",
        "sheffield_hallam_university_forced_labor_reports_entity_adjacent",
        "former_soe",
        "reputational_risk_organized_crime",
        "reputational_risk_forced_labor",
        "imports_bis_high_priority_items_critical_components",
        "owner_of_sheffield_hallam_university_reports_forced_labor_entity",
        "cpi_score",
        "psa_sheffield_hallam_university_useful_resources",
        "psa_wro_entity",
        "psa_entity_licensed_with_fsb_rf",
        "forced_labor_wro_origin_subtier_product_blueprint",
        "psa_forced_labor_xinjiang_uflpa",
        "owner_of_wro_entity",
        "military_civil_fusion",
        "forced_labor_xinjiang_registration",
        "forced_labor_xinjiang_name",
        "owned_by_aspi_forced_labor_entity",
        "reputational_risk_terrorism",
        "formerly_sanctioned",
        "owned_by_section_1260h_entity",
        "sheffield_hallam_university_forced_labor_reports_intermediary_entity",
        "pep_adjacent",
        "owner_of_forced_labor_xinjiang_entity",
        "law_enforcement_action",
        "owned_by_soe",
        "owned_by_military_civil_fusion",
        "entity_licensed_with_fsb_rf",
        "psa_forced_labor_xinjiang_registration",
        "forced_labor_sheffield_hallam_university_reports_origin_direct",
        "psa_forced_labor_xinjiang_geospatial",
        "wro_entity_adjacent",
        "reputational_risk_cybercrime",
        "psa_forced_labor_xinjiang_operations",
        "owner_of_soe",
        "psa_bis_boycott_requester_list",
        "forced_labor_aspi_origin_direct",
        "exports_bis_high_priority_items",
        "forced_labor_uflpa_origin_subtier",
        "owner_of_regulatory_action_entity",
        "psa_sheffield_hallam_university_intermediary_entity",
        "forced_labor_xinjiang_uflpa",
        "psa_state_owned",
        "forced_labor_uflpa_origin_direct",
        "forced_labor_xinjiang_origin_subtier_product_blueprint",
        "owned_by_sanctioned_entity",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from .coordinates import Coordinates
from .entity_search_response import EntitySearchResponse
from .filter_list import FilterList
from .record_search_response import RecordSearchResponse
from .search_results import SearchResults
from .source_id import SourceId

__all__ = ["Coordinates", "EntitySearchResponse", "FilterList", "RecordSearchResponse", "SearchResults", "SourceId"]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from ...generated_types.types.risk import Risk
from .business_purpose import BusinessPurpose
from ...generated_types.types.country import Country
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class SourceOrDestinationEntity(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    Unique identifier of the entity
    """

    names: typing.List[str]
    risks: typing.Dict[Risk, typing.Optional[typing.Any]] = pydantic.Field()
    """
    [Risks](/sayari-library/ontology/risk-factors)
    """

    business_purpose: typing.List[BusinessPurpose] = pydantic.Field()
    """
    [Business Purpose](/sayari-library/ontology/enumerated-types#business-purpose-standard)
    """

    countries: typing.List[Country] = pydantic.Field()
    """
    [Countries](/sayari-library/ontology/enumerated-types#country)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .bad_gateway import BadGateway
from .bad_request import BadRequest
from .connection_error import ConnectionError
from .internal_server_error import InternalServerError
from .method_not_allowed import MethodNotAllowed
from .not_acceptable import NotAcceptable
from .not_found import NotFound
from .rate_limit_exceeded import RateLimitExceeded
from .unauthorized import Unauthorized

__all__ = [
    "BadGateway",
    "BadRequest",
    "ConnectionError",
    "InternalServerError",
    "MethodNotAllowed",
    "NotAcceptable",
    "NotFound",
    "RateLimitExceeded",
    "Unauthorized",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .trade_traversal_path import TradeTraversalPath
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class UpstreamTradeTraversalResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.supply_chain import (
        HsCodeWithDescription,
        TradeTraversalEntity,
        TradeTraversalPath,
        TradeTraversalPathSegment,
        TradeTraversalProduct,
        UpstreamTradeTraversalResponse,
    )

    UpstreamTradeTraversalResponse(
        data=[
            TradeTraversalPath(
                source="ESkH7J-UCRfY5t0_JXIH3w",
                target=TradeTraversalEntity(
                    id="BAQGiWn9riAG10h4NuK_9w",
                    type="company",
                    label="TEXMARK CHEMICALS INC",
                    countries=["USA"],
                    risk=["forced_labor_xinjiang_origin_subtier"],
                ),
                path=[
                    TradeTraversalPathSegment(
                        entity=TradeTraversalEntity(
                            id="ESkH7J-UCRfY5t0_JXIH3w",
                            type="company",
                            label="ACUMEN HOUSEWARE INDUSTRY VIETNAM CO LTD",
                            countries=["VNM"],
                            risk=[],
                        ),
                        products=[
                            TradeTraversalProduct(
                                hs_code=HsCodeWithDescription(
                                    code="3204",
                                    description="Synthetic dyes & agents",
                                ),
                                min_date="2023-04-01",
                                max_date="2024-03-27",
                                arrival_countries=["VNM"],
                                departure_countries=["IND"],
                            )
                        ],
                    ),
                    TradeTraversalPathSegment(
                        entity=TradeTraversalEntity(
                            id="A84F35yJ_3FT_hVzD9EzAw",
                            type="company",
                            label="TOYO INK INDIA PRIVATE LIMITED",
                            countries=["IND"],
                            risk=[
                                "forced_labor_sheffield_hallam_university_reports_origin_subtier",
                                "forced_labor_uflpa_origin_subtier",
                                "forced_labor_xinjiang_origin_subtier",
                            ],
                        ),
                        products=[
                            TradeTraversalProduct(
                                hs_code=HsCodeWithDescription(
                                    code="3206",
                                    description="Other dyes & colorants",
                                ),
                                min_date="2023-03-01",
                                max_date="2024-02-12",
                                arrival_countries=["IND"],
                                departure_countries=["CHN"],
                            )
                        ],
                    ),
                ],
            )
        ],
    )
    """

    status: typing.Optional[int] = None
    success: typing.Optional[bool] = None
    message: typing.Optional[str] = None
    data: typing.List[TradeTraversalPath]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .qualified_count import QualifiedCount
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class PaginatedResponse(UniversalBaseModel):
    """
    Response fields that represent unbounded collections, such as a search result or an entity's attributes or relationships, or a record's references, can all be paginated in cases where the collection is larger than can be efficiently returned in a single request.
    """

    limit: int
    size: QualifiedCount

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .match_explanation import MatchExplanation
from .match_quality import MatchQuality
from .match_strength import MatchStrength
from .profile_enum import ProfileEnum
from .resolution_body import ResolutionBody
from .resolution_persisted_response import ResolutionPersistedResponse
from .resolution_persisted_response_fields import ResolutionPersistedResponseFields
from .resolution_persisted_result import ResolutionPersistedResult
from .resolution_response import ResolutionResponse
from .resolution_response_fields import ResolutionResponseFields
from .resolution_result import ResolutionResult

__all__ = [
    "MatchExplanation",
    "MatchQuality",
    "MatchStrength",
    "ProfileEnum",
    "ResolutionBody",
    "ResolutionPersistedResponse",
    "ResolutionPersistedResponseFields",
    "ResolutionPersistedResult",
    "ResolutionResponse",
    "ResolutionResponseFields",
    "ResolutionResult",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ...generated_types.types.both_identifier_types import BothIdentifierTypes
from ...generated_types.types.country import Country
from ...generated_types.types.entities import Entities
from .profile_enum import ProfileEnum
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ResolutionBody(UniversalBaseModel):
    name: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Entity name
    """

    identifier: typing.Optional[typing.List[BothIdentifierTypes]] = pydantic.Field(default=None)
    """
    Entity identifier. Can be from either the [Identifier Type](/sayari-library/ontology/enumerated-types#identifier-type) or [Weak Identifier Type](/sayari-library/ontology/enumerated-types#weak-identifier-type) enums.
    """

    address: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Entity address
    """

    city: typing.Optional[str] = pydantic.Field(default=None)
    """
    Entity city that contains the provided city name.
    """

    state: typing.Optional[str] = pydantic.Field(default=None)
    """
    Entity state that contains the provided state name.
    """

    country: typing.Optional[typing.List[Country]] = pydantic.Field(default=None)
    """
    Entity country - must be ISO (3166) Trigram i.e., `USA`. See complete list [here](/sayari-library/ontology/enumerated-types#country)
    """

    date_of_birth: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Entity date of birth
    """

    contact: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Entity contact
    """

    type: typing.Optional[typing.List[Entities]] = pydantic.Field(default=None)
    """
    [Entity type](/sayari-library/ontology/entities). If multiple values are passed for any field, the endpoint will match entities with ANY of the values.
    """

    profile: typing.Optional[ProfileEnum] = pydantic.Field(default=None)
    """
    Profile can be used to switch between search algorithms. The default profile `corporate` is optimized for accurate entity attribute matching and is ideal for business verification and matching entities with corporate data. The `suppliers` profile is optimized for matching entities with extensive trade data. Ideal for supply chain and trade-related use cases.
    """

    name_min_percentage: typing.Optional[int] = pydantic.Field(default=None)
    """
    Adding this param enables an alternative matching logic. It will set a minimum percentage of tokens needed to match with user input to be considered a "hit". Accepts integers from 0 to 100 inclusive.
    """

    name_min_tokens: typing.Optional[int] = pydantic.Field(default=None)
    """
    Adding this param enables an alternative matching logic. It sets the minimum number of matching tokens the resolved hits need to have in common with the user input to be considered a "hit". Accepts non-negative integers.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing_extensions
import typing
from ...core.serialization import FieldMetadata
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class UserInfo(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    Currently logged in user ID
    """

    group_display_names: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="groupDisplayNames")] = (
        pydantic.Field(default=None)
    )
    """
    Name of the sayari organization tied to credentials
    """

    roles: typing.Optional[str] = pydantic.Field(default=None)
    """
    Licenses associated with the organization
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

MonetaryValueContext = typing.Union[
    typing.Literal["cost_insurance_and_freight", "free_on_board", "assessed_value"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...shared_types.types.entity_details import EntityDetails
from ...shared_types.types.entity_relationships import EntityRelationships
from ...shared_types.types.relationship_data import RelationshipData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic
from ...core.pydantic_utilities import update_forward_refs


class EntitySummaryResponse(EntityDetails):
    """
    OK

    Examples
    --------
    from sayari.base_types import QualifiedCount
    from sayari.entity import EntitySummaryResponse
    from sayari.generated_types import (
        AddressData,
        AddressInfo,
        AddressProperties,
        AttributeDetails,
        BusinessPurposeData,
        BusinessPurposeInfo,
        BusinessPurposeProperties,
        CompanyTypeData,
        CompanyTypeInfo,
        CompanyTypeProperties,
        CountryData,
        CountryInfo,
        CountryProperties,
        IdentifierData,
        IdentifierInfo,
        IdentifierProperties,
        NameData,
        NameInfo,
        NameProperties,
        StatusData,
        StatusInfo,
        StatusProperties,
    )
    from sayari.shared_types import (
        Identifier,
        PossiblySameAs,
        PossiblySameAsData,
        PsaEntity,
        RecordDetails,
        ReferencedBy,
        ReferencedByData,
        RiskData,
        SourceCountInfo,
        Status,
    )

    EntitySummaryResponse(
        id="mGq1lpuqKssNWTjIokuPeA",
        label="VICTORIA BECKHAM LIMITED",
        degree=67,
        entity_url="/entity/mGq1lpuqKssNWTjIokuPeA",
        pep=False,
        psa_id="695785012897",
        psa_count=3,
        sanctioned=False,
        closed=False,
        company_type="Stock Corporation - Out of State - Stock",
        registration_date="Incorporated 2008-02-28",
        latest_status=Status(
            status="active",
            date="2023-08-29",
        ),
        trade_count={"sent": 41, "received": 0},
        type="company",
        identifiers=[
            Identifier(
                value="06517802",
                type="uk_company_number",
                label="Uk Company Number",
            ),
            Identifier(
                value="6517802",
                type="unknown",
                label="Unknown",
            ),
            Identifier(
                value="04781466",
                type="ca_corporate_id_num",
                label="Ca Corporate Id Num",
            ),
        ],
        addresses=[
            "202 HAMMERSMITH ROAD , LONDON , , UNITED KINGDOM , W6 7DN , GB",
            "Unit 33, Ransomes Dock Business Centre, 35-37 Parkgate Road, London SW11 4NP",
            "SAUNDERS BUILDING, 202 HAMMERSMITH ROAD, HAMMERSMITH, LONDON",
        ],
        countries=["GBR", "USA"],
        relationship_count={
            "linked_to": 3,
            "has_officer": 2,
            "shareholder_of": 1,
            "has_shareholder": 2,
            "has_registered_agent": 5,
            "shipper_of": 41,
            "has_director": 11,
            "owner_of": 3,
            "has_founder": 1,
            "ships_to": 1,
        },
        source_count={
            "2b618f1996252fe537a6d998ae14c9b2": SourceCountInfo(
                count=1,
                label="UK Corporate Registry Confirmation Statements",
            ),
            "2b788dbdf9194ed5a5c309386a6516b1": SourceCountInfo(
                count=28,
                label="UK HM Revenue & Customs Traders Database",
            ),
            "a447a7b622c4ead6e1caf94983dc2337": SourceCountInfo(
                count=6,
                label="USA California Secretary of State",
            ),
            "ecdfb3f2ecc8c3797e77d5795a8066ef": SourceCountInfo(
                count=35,
                label="UK Corporate Registry",
            ),
            "e5de7b52cc88ef4cd1a10e201bdf46ee": SourceCountInfo(
                count=41,
                label="Vietnam Imports & Exports (January 2023 - Present)",
            ),
            "2a4fe9a14e332c8f9ded1f8a457c2b89": SourceCountInfo(
                count=36,
                label="UK Land Commercial and Corporate Ownership Data (CCOD)",
            ),
            "4ea8bac1bed868e1510ffd21842e9551": SourceCountInfo(
                count=69,
                label="UK Persons with Significant Control",
            ),
        },
        risk={
            "basel_aml": RiskData(
                value=4.63,
                metadata={"country": ["USA"]},
                level="relevant",
            ),
            "cpi_score": RiskData(
                value=67.0,
                metadata={"country": ["USA"]},
                level="relevant",
            ),
        },
        user_attribute_count={},
        user_record_count=0,
        user_related_entities_count=0,
        user_relationship_count={},
        related_entities_count=67,
        attribute_count={
            "company_type": 2,
            "name": 2,
            "business_purpose": 4,
            "identifier": 3,
            "additional_information": 106,
            "country": 8,
            "status": 5,
            "address": 7,
        },
        reference_id="ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000:4a34442eccf1622995130b194a5d50e7",
        attributes=AttributeDetails(
            name=NameInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=2,
                    qualifier="eq",
                ),
                data=[
                    NameData(
                        properties=NameProperties(
                            value="BECKHAM VENTURES LIMITED",
                            context="alias",
                            to_date="2014-09-03",
                        ),
                        record=[
                            "2a4fe9a14e332c8f9ded1f8a457c2b89/NGL944625/1560779151522"
                        ],
                        record_count=30,
                    ),
                    NameData(
                        properties=NameProperties(
                            value="VICTORIA BECKHAM LIMITED",
                            context="primary",
                        ),
                        record=[
                            "ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000"
                        ],
                        record_count=157,
                    ),
                ],
            ),
            address=AddressInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=7,
                    qualifier="eq",
                ),
                data=[
                    AddressData(
                        properties=AddressProperties(
                            value="202 HAMMERSMITH ROAD UNITED KINGDOM",
                            house_number="202",
                            road="Hammersmith Road",
                            country="United Kingdom",
                            x=-0.22579,
                            y=51.49291,
                            precision_code="G3",
                            normalized="202 HAMMERSMITH KINGDOM RD UNITED",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1678752000000"
                        ],
                        record_count=5,
                    ),
                    AddressData(
                        properties=AddressProperties(
                            value="Unit 33, Ransomes Dock Business Centre, 35-37 Parkgate Road, London SW11 4NP",
                            house="Ransomes Dock Business Centre",
                            house_number="35-37",
                            unit="Unit 33",
                            road="Parkgate Road",
                            city="London",
                            postcode="Sw11 4np",
                            x=-0.16859,
                            y=51.47943,
                            precision_code="S8HPNTSCZA",
                            normalized="33 35 37 4NP BUSINESS CTR DOCK LONDON PARKGATE RANSOMES RD SW11 UNIT",
                        ),
                        record=[
                            "2a4fe9a14e332c8f9ded1f8a457c2b89/BGL137643/1560779151522"
                        ],
                        record_count=36,
                    ),
                    AddressData(
                        properties=AddressProperties(
                            value="202 HAMMERSMITH ROAD BRITISH ISLES",
                            house_number="202",
                            road="Hammersmith Road British Isles",
                            normalized="202 BRITISH HAMMERSMITH ISLE RD",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=1,
                    ),
                    AddressData(
                        properties=AddressProperties(
                            value="SAUNDERS BUILDING, 202 HAMMERSMITH ROAD, HAMMERSMITH, LONDON",
                            house="Saunders Building",
                            house_number="202",
                            road="Hammersmith Road",
                            suburb="Hammersmith",
                            city="London",
                            postcode="W6 7DN",
                            x=-0.22207,
                            y=51.49323,
                            precision_code="S8HPNTSC-A",
                            normalized="202 BUILDING HAMMERSMITH HAMMERSMITH LONDON RD SAUNDERS",
                        ),
                        record=[
                            "2b788dbdf9194ed5a5c309386a6516b1/213bcb98d1409787c3b3f668794fd233/1672444800000"
                        ],
                        record_count=28,
                    ),
                    AddressData(
                        properties=AddressProperties(
                            value="Ransome's Dock, 35-37 Parkgate Road, London, SW11 4NP",
                            house="Ransome's Dock",
                            house_number="35-37",
                            road="Parkgate Road",
                            city="London",
                            postcode="SW11 4NP",
                            x=-0.16784,
                            y=51.47898,
                            precision_code="S8HPNTSC-A",
                            normalized="35 37 4NP DOCK LONDON PARKGATE RANSOMES RD SW11",
                        ),
                        record=[
                            "4ea8bac1bed868e1510ffd21842e9551/08661308/1560176240192"
                        ],
                        record_count=15,
                    ),
                    AddressData(
                        properties=AddressProperties(
                            value="202 HAMMERSMITH ROAD , LONDON , , UNITED KINGDOM , W6 7DN , GB",
                            house_number="202",
                            road="Hammersmith Road",
                            city="London",
                            postcode="W6 7dn",
                            country="Gb",
                            x=-0.22207,
                            y=51.49323,
                            precision_code="S8HPNTSCZA",
                            normalized="202 7DN GB HAMMERSMITH KINGDOM LONDON RD UNITED W6",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=59,
                    ),
                    AddressData(
                        properties=AddressProperties(
                            value="Hammersmith Road, London, W6 7DN",
                            road="Hammersmith Road",
                            city="London",
                            postcode="W6 7DN",
                            x=-0.22138000000000002,
                            y=51.493080000000006,
                            precision_code="S4-PNTSCZA",
                            normalized="7DN HAMMERSMITH LONDON RD W6",
                        ),
                        record=[
                            "4ea8bac1bed868e1510ffd21842e9551/ef8cbb3fcc71d09f098f00728df231e8/1694476800000"
                        ],
                        record_count=8,
                    ),
                ],
            ),
            identifier=IdentifierInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=3,
                    qualifier="eq",
                ),
                data=[
                    IdentifierData(
                        properties=IdentifierProperties(
                            value="04781466",
                            type="ca_corporate_id_num",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    IdentifierData(
                        properties=IdentifierProperties(
                            value="06517802",
                            type="uk_company_number",
                        ),
                        record=[
                            "ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000"
                        ],
                        record_count=126,
                    ),
                    IdentifierData(
                        properties=IdentifierProperties(
                            value="6517802",
                            type="unknown",
                        ),
                        record=[
                            "4ea8bac1bed868e1510ffd21842e9551/08661308/1560176240192"
                        ],
                        record_count=15,
                    ),
                ],
            ),
            status=StatusInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=5,
                    qualifier="eq",
                ),
                data=[
                    StatusData(
                        properties=StatusProperties(
                            text="Good",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    StatusData(
                        properties=StatusProperties(
                            value="incorporated",
                            date="2008-02-28",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=18,
                    ),
                    StatusData(
                        properties=StatusProperties(
                            text="Good",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    StatusData(
                        properties=StatusProperties(
                            value="active",
                            text="Active",
                            date="2023-08-29",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=24,
                    ),
                    StatusData(
                        properties=StatusProperties(
                            value="registered",
                            text="INITIAL_FILING_DATE",
                            date="2021-08-24",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                ],
            ),
            company_type=CompanyTypeInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=2,
                    qualifier="eq",
                ),
                data=[
                    CompanyTypeData(
                        properties=CompanyTypeProperties(
                            value="Stock Corporation - Out of State - Stock",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    CompanyTypeData(
                        properties=CompanyTypeProperties(
                            value="Private Limited Company",
                        ),
                        record=[
                            "4ea8bac1bed868e1510ffd21842e9551/08661308/1560176240192"
                        ],
                        record_count=41,
                    ),
                ],
            ),
            business_purpose=BusinessPurposeInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=4,
                    qualifier="eq",
                ),
                data=[
                    BusinessPurposeData(
                        properties=BusinessPurposeProperties(
                            value="Other amusement and recreation activities n.e.c.",
                            code="9329",
                            standard="ISIC4",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=18,
                    ),
                    BusinessPurposeData(
                        properties=BusinessPurposeProperties(
                            value="LADIES FASHION",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    BusinessPurposeData(
                        properties=BusinessPurposeProperties(
                            value="Other amusement and recreation activities n.e.c.",
                            code="93290",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=18,
                    ),
                    BusinessPurposeData(
                        properties=BusinessPurposeProperties(
                            value="Other amusement and recreation activities",
                            code="93.29",
                            standard="NACE2",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=18,
                    ),
                ],
            ),
            country=CountryInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=8,
                    qualifier="eq",
                ),
                data=[
                    CountryData(
                        properties=CountryProperties(
                            value="GBR",
                            context="address",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=23,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="GBR",
                            context="activity_in",
                        ),
                        record=[
                            "ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000"
                        ],
                        record_count=82,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="GBR",
                            context="domicile",
                        ),
                        record=[
                            "4ea8bac1bed868e1510ffd21842e9551/ef8cbb3fcc71d09f098f00728df231e8/1694476800000"
                        ],
                        record_count=8,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="USA",
                            context="domicile",
                            state="US-DE",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="GBR",
                            context="address",
                        ),
                        record=[
                            "e5de7b52cc88ef4cd1a10e201bdf46ee/{4DC73DBC-FC75-42F3-8A4AAED3254239E1}/1690329600000"
                        ],
                        record_count=41,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="USA",
                            context="activity_in",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="GBR",
                            context="mentioned_in",
                        ),
                        record=[
                            "ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000"
                        ],
                        record_count=141,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="USA",
                            context="mentioned_in",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                ],
            ),
        ),
        possibly_same_as=PossiblySameAs(
            limit=50,
            size=QualifiedCount(
                count=3,
                qualifier="eq",
            ),
            offset=0,
            next=false,
            data=[
                PossiblySameAsData(
                    entity=PsaEntity(
                        id="NGUTEUTI4YZ6R5d56vgNIw",
                        label="BECKHAM VENTURES INC.",
                        degree=3,
                        entity_url="/entity/NGUTEUTI4YZ6R5d56vgNIw",
                        pep=False,
                        psa_id="695785012897",
                        psa_count=3,
                        sanctioned=False,
                        closed=False,
                        company_type="FOREIGN BUSINESS CORPORATION",
                        registration_date=" 2013-01-16",
                        latest_status=Status(
                            status="active",
                            date="2013-01-16",
                        ),
                        trade_count={"sent": 0, "received": 0},
                        type="company",
                        identifiers=[
                            Identifier(
                                value="4346762",
                                type="usa_ny_dos_id",
                                label="Usa Ny Dos Id",
                            )
                        ],
                        addresses=[
                            "99 WASHINGTON AVE., SUITE 805A, ALBANY, NY, 12201",
                            "511 WEST 25TH STREET, SUITE # 701/7TH FLOOR, NEW YORK, NEW YORK, 10001",
                            "80 STATE STREET, ALBANY, NEW YORK, 12207-2543",
                        ],
                        countries=["USA"],
                        relationship_count={
                            "has_officer": 1,
                            "has_registered_agent": 2,
                            "linked_to": 2,
                        },
                        source_count={
                            "b4d06d4b77f51fab3c77c9653aabdda4": SourceCountInfo(
                                count=8,
                                label="USA New York Corporate Registry (Active Entities)",
                            )
                        },
                        risk={
                            "basel_aml": RiskData(
                                value=4.63,
                                metadata={"country": ["USA"]},
                                level="relevant",
                            ),
                            "cpi_score": RiskData(
                                value=67.0,
                                metadata={"country": ["USA"]},
                                level="relevant",
                            ),
                        },
                        user_attribute_count={},
                        user_record_count=0,
                        user_related_entities_count=0,
                        user_relationship_count={},
                        related_entities_count=3,
                        attribute_count={
                            "company_type": 1,
                            "name": 1,
                            "identifier": 1,
                            "country": 3,
                            "status": 1,
                            "address": 3,
                        },
                        reference_id="b4d06d4b77f51fab3c77c9653aabdda4/a80e7f4c-c219-437b-9941-32d89ea5885a/1560542045043:15d813b260619393762864f22d3c5b2d",
                    ),
                    matches={},
                ),
                PossiblySameAsData(
                    entity=PsaEntity(
                        id="Fv6k3Wmcq8fKdLoDLQM_Xw",
                        label="BECKHAM VENTURES INC.",
                        degree=1,
                        entity_url="/entity/Fv6k3Wmcq8fKdLoDLQM_Xw",
                        pep=False,
                        psa_id="695785012897",
                        psa_count=3,
                        sanctioned=False,
                        closed=False,
                        company_type="GENERAL",
                        registration_date="Incorporated 2013-01-14",
                        trade_count={"sent": 0, "received": 0},
                        type="company",
                        identifiers=[
                            Identifier(
                                value="5273939",
                                type="usa_de_file_number",
                                label="Usa De File Number",
                            )
                        ],
                        addresses=[],
                        countries=["USA"],
                        relationship_count={"has_registered_agent": 1},
                        source_count={
                            "29ec06417b900ffe3fedd42d02b1b6d7": SourceCountInfo(
                                count=1,
                                label="USA Delaware Secretary of State",
                            )
                        },
                        risk={
                            "basel_aml": RiskData(
                                value=4.63,
                                metadata={"country": ["USA"]},
                                level="relevant",
                            ),
                            "cpi_score": RiskData(
                                value=67.0,
                                metadata={"country": ["USA"]},
                                level="relevant",
                            ),
                        },
                        user_attribute_count={},
                        user_record_count=0,
                        user_related_entities_count=0,
                        user_relationship_count={},
                        related_entities_count=1,
                        attribute_count={
                            "company_type": 1,
                            "name": 1,
                            "identifier": 1,
                            "country": 2,
                            "status": 1,
                        },
                        reference_id="985b4533cd1cb2db1d736dd31f8e34c9/January 2013.pdf/1643737587282:f1b8f7a9ed23af356dcd37ce6c3ea059",
                    ),
                    matches={},
                ),
                PossiblySameAsData(
                    entity=PsaEntity(
                        id="EINtsur0kjyyS7w7ObvhBA",
                        label="VICTORIA BECKHAM LIMITED",
                        degree=1,
                        entity_url="/entity/EINtsur0kjyyS7w7ObvhBA",
                        pep=False,
                        psa_id="695785012897",
                        psa_count=3,
                        sanctioned=False,
                        closed=False,
                        trade_count={"sent": 0, "received": 0},
                        type="company",
                        identifiers=[],
                        addresses=[
                            "ST CHRISTOPHER'S PLACE   NUM. EXT. 4 GEE'S COURT NUM. INT. C/O LEE & THOMPSON LLP"
                        ],
                        countries=["GBR", "MEX"],
                        relationship_count={"owner_of": 1},
                        source_count={
                            "b9d809b02049993ba8dc2e4c5f7cceca": SourceCountInfo(
                                count=16,
                                label="Mexico Industrial Property Trademark Registry (MARCIA)",
                            )
                        },
                        risk={
                            "basel_aml": RiskData(
                                value=3.99,
                                metadata={"country": ["GBR"]},
                                level="relevant",
                            ),
                            "cpi_score": RiskData(
                                value=78.0,
                                metadata={"country": ["GBR"]},
                                level="relevant",
                            ),
                        },
                        user_attribute_count={},
                        user_record_count=0,
                        user_related_entities_count=0,
                        user_relationship_count={},
                        related_entities_count=1,
                        attribute_count={"name": 1, "address": 1, "country": 2},
                        reference_id="b9d809b02049993ba8dc2e4c5f7cceca/RM201902324751/1590507065822:5289443ba2cdf59a7c656b77584a49fc",
                    ),
                    matches={},
                ),
            ],
        ),
        referenced_by=ReferencedBy(
            limit=50,
            size=QualifiedCount(
                count=216,
                qualifier="eq",
            ),
            offset=0,
            next=true,
            data=[
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{D634B9B1-39E2-4273-8F35AE81130E18D7}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BD634B9B1-39E2-4273-8F35AE81130E18D7%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{BFC9056E-9711-49CC-AC6B4F3D19809ABC}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BBFC9056E-9711-49CC-AC6B4F3D19809ABC%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{B6BE3A73-D320-44B8-875BC573F54210FD}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BB6BE3A73-D320-44B8-875BC573F54210FD%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{8A7A08E2-123B-4FAE-94BF66C6F3BA6BEA}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B8A7A08E2-123B-4FAE-94BF66C6F3BA6BEA%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{5A8089A5-891D-43C4-BEA50DCB4D32401E}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B5A8089A5-891D-43C4-BEA50DCB4D32401E%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{596910C7-D648-4A2C-BFFA77F966A8962D}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B596910C7-D648-4A2C-BFFA77F966A8962D%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{4756305B-2033-40A4-9BD867B6EFA8C9B2}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B4756305B-2033-40A4-9BD867B6EFA8C9B2%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{32A66456-B070-4F55-8D117D740BED2ECF}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B32A66456-B070-4F55-8D117D740BED2ECF%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{22B19094-CEDF-4100-BDC2CA091A4FF5A9}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B22B19094-CEDF-4100-BDC2CA091A4FF5A9%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{1AD11C10-D7D6-4504-B5CC9E6177795A0E}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B1AD11C10-D7D6-4504-B5CC9E6177795A0E%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{F71CAC67-4F08-48D5-A15EFCA682205705}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BF71CAC67-4F08-48D5-A15EFCA682205705%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{F450EB48-AF31-44EC-92D47886A3CEB625}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BF450EB48-AF31-44EC-92D47886A3CEB625%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{B7F7DA58-63AF-461B-B708FC2C7514355F}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BB7F7DA58-63AF-461B-B708FC2C7514355F%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{968CEF6C-F2CA-4298-9D33475268924C3A}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B968CEF6C-F2CA-4298-9D33475268924C3A%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{952E6357-B36F-4802-A5B3E84AAA42CE8E}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B952E6357-B36F-4802-A5B3E84AAA42CE8E%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{72007C6B-740B-451A-BD4C61114679B8EF}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B72007C6B-740B-451A-BD4C61114679B8EF%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{70EEEDF9-BD5C-4770-8EF76D52CB6DC0EE}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B70EEEDF9-BD5C-4770-8EF76D52CB6DC0EE%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{5EBBA4A9-153C-4243-86675561CE321275}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B5EBBA4A9-153C-4243-86675561CE321275%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{4D2F724B-B98C-4D5D-A98E8ADC8C2C46FF}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B4D2F724B-B98C-4D5D-A98E8ADC8C2C46FF%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{4B4E435B-3975-4345-8177CF444DCF7324}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B4B4E435B-3975-4345-8177CF444DCF7324%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{44A3E2B5-901D-4360-9DEB8EF35019ED15}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B44A3E2B5-901D-4360-9DEB8EF35019ED15%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{428CEE8F-F33B-4598-97CE9C6CCDFBF8DD}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B428CEE8F-F33B-4598-97CE9C6CCDFBF8DD%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{2F726716-BED1-4AE0-A1A616900B61F1E3}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B2F726716-BED1-4AE0-A1A616900B61F1E3%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{247A2589-CDBF-47CD-9067FB972808C874}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B247A2589-CDBF-47CD-9067FB972808C874%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{F5C41EC6-EE88-4121-BCAD5AA81E93C00B}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BF5C41EC6-EE88-4121-BCAD5AA81E93C00B%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{D6757BC6-2BCF-4D87-A3F53F99025121E8}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BD6757BC6-2BCF-4D87-A3F53F99025121E8%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{D0885822-D92D-42BE-8CDB4FA889F1E2B4}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BD0885822-D92D-42BE-8CDB4FA889F1E2B4%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{C117BC85-81E6-40D1-A61DF66FD04694AF}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BC117BC85-81E6-40D1-A61DF66FD04694AF%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{AD48A141-FA80-4F09-B97229C9DBA3367D}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BAD48A141-FA80-4F09-B97229C9DBA3367D%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{A98A356D-E3EE-427D-9FE5E8481C2D5890}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BA98A356D-E3EE-427D-9FE5E8481C2D5890%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{988597F4-E258-4342-983E7D7B38C539CB}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B988597F4-E258-4342-983E7D7B38C539CB%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{82552661-B818-48A7-BE6962B7C6E89DD2}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B82552661-B818-48A7-BE6962B7C6E89DD2%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{575FEE26-922F-401D-AE815061380066BB}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B575FEE26-922F-401D-AE815061380066BB%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{4DC73DBC-FC75-42F3-8A4AAED3254239E1}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B4DC73DBC-FC75-42F3-8A4AAED3254239E1%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{3E4B4DE7-CFF4-43B2-831C9CE5D2B21D94}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B3E4B4DE7-CFF4-43B2-831C9CE5D2B21D94%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{3B5D2BEC-8F38-4DC0-86C2C4C20A37176E}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B3B5D2BEC-8F38-4DC0-86C2C4C20A37176E%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{3059B414-F15D-4D7C-A85D09A31FA0D600}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B3059B414-F15D-4D7C-A85D09A31FA0D600%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{2D68218F-1C6A-4809-98AA6B06BB09EF74}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B2D68218F-1C6A-4809-98AA6B06BB09EF74%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{24036F32-7BD0-4E22-8DB93CAFDD940917}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B24036F32-7BD0-4E22-8DB93CAFDD940917%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{186A7E83-88B9-4D9D-B9B7B5E2E41FF046}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B186A7E83-88B9-4D9D-B9B7B5E2E41FF046%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{1263162D-9752-4A73-86224B2242C245F5}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B1263162D-9752-4A73-86224B2242C245F5%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="9139b58de1bdb0157a1a1e54e56df6d3/4781466/1709769600000",
                        label="Company Record from USA California Secretary of State",
                        source="a447a7b622c4ead6e1caf94983dc2337",
                        publication_date="2024-03-07",
                        acquisition_date="2024-03-07",
                        references_count=5,
                        record_url="/record/9139b58de1bdb0157a1a1e54e56df6d3%2F4781466%2F1709769600000",
                        source_url="https://bizfileonline.sos.ca.gov/search/business",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="9139b58de1bdb0157a1a1e54e56df6d3/4781466/1701648000000",
                        label="Company Record from USA California Secretary of State",
                        source="a447a7b622c4ead6e1caf94983dc2337",
                        publication_date="2023-12-04",
                        acquisition_date="2023-12-04",
                        references_count=4,
                        record_url="/record/9139b58de1bdb0157a1a1e54e56df6d3%2F4781466%2F1701648000000",
                        source_url="https://bizfileonline.sos.ca.gov/search/business",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="9139b58de1bdb0157a1a1e54e56df6d3/4781466/1693872000000",
                        label="Company Record from USA California Secretary of State",
                        source="a447a7b622c4ead6e1caf94983dc2337",
                        publication_date="2023-09-05",
                        acquisition_date="2023-09-05",
                        references_count=4,
                        record_url="/record/9139b58de1bdb0157a1a1e54e56df6d3%2F4781466%2F1693872000000",
                        source_url="https://bizfileonline.sos.ca.gov/search/business",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="9139b58de1bdb0157a1a1e54e56df6d3/4781466/1685664000000",
                        label="Company Record from USA California Secretary of State",
                        source="a447a7b622c4ead6e1caf94983dc2337",
                        publication_date="2023-06-02",
                        acquisition_date="2023-06-02",
                        references_count=4,
                        record_url="/record/9139b58de1bdb0157a1a1e54e56df6d3%2F4781466%2F1685664000000",
                        source_url="https://bizfileonline.sos.ca.gov/search/business",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="9139b58de1bdb0157a1a1e54e56df6d3/4781466/1678752000000",
                        label="Company Record from USA California Secretary of State",
                        source="a447a7b622c4ead6e1caf94983dc2337",
                        publication_date="2023-03-14",
                        acquisition_date="2023-03-14",
                        references_count=4,
                        record_url="/record/9139b58de1bdb0157a1a1e54e56df6d3%2F4781466%2F1678752000000",
                        source_url="https://bizfileonline.sos.ca.gov/search/business",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000",
                        label="Company Record from USA California Secretary of State",
                        source="a447a7b622c4ead6e1caf94983dc2337",
                        publication_date="2022-04-05",
                        acquisition_date="2022-04-05",
                        references_count=4,
                        record_url="/record/9139b58de1bdb0157a1a1e54e56df6d3%2F4781466%2F1649116800000",
                        source_url="https://bizfileonline.sos.ca.gov/search/business",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1706054400000",
                        label="Company Record from UK Corporate Registry",
                        source="ecdfb3f2ecc8c3797e77d5795a8066ef",
                        publication_date="2024-01-24",
                        acquisition_date="2024-01-24",
                        references_count=16,
                        record_url="/record/ecdfb3f2ecc8c3797e77d5795a8066ef%2F06517802%2F1706054400000",
                        source_url="https://beta.companieshouse.gov.uk/company/",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1680566400000",
                        label="Company Record from UK Corporate Registry",
                        source="ecdfb3f2ecc8c3797e77d5795a8066ef",
                        publication_date="2023-04-04",
                        acquisition_date="2023-04-04",
                        references_count=9,
                        record_url="/record/ecdfb3f2ecc8c3797e77d5795a8066ef%2F06517802%2F1680566400000",
                        source_url="https://beta.companieshouse.gov.uk/company/",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1677542400000",
                        label="Company Record from UK Corporate Registry",
                        source="ecdfb3f2ecc8c3797e77d5795a8066ef",
                        publication_date="2023-02-28",
                        acquisition_date="2023-02-28",
                        references_count=9,
                        record_url="/record/ecdfb3f2ecc8c3797e77d5795a8066ef%2F06517802%2F1677542400000",
                        source_url="https://beta.companieshouse.gov.uk/company/",
                    ),
                    type="about",
                ),
            ],
        ),
    )
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EntityDetails, EntitySummaryResponse=EntitySummaryResponse)
update_forward_refs(EntityRelationships, EntitySummaryResponse=EntitySummaryResponse)
update_forward_refs(RelationshipData, EntitySummaryResponse=EntitySummaryResponse)



# This file was auto-generated by Fern from our API Definition.

import typing

NameContext = typing.Union[
    typing.Literal["primary", "given", "family", "alias", "machine_translation", "transliteration", "trade_name"],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from .resolution_response_fields import ResolutionResponseFields
import typing_extensions
import typing
from ...core.serialization import FieldMetadata
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ResolutionPersistedResponseFields(ResolutionResponseFields):
    custom_field_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="custom_{field name}")] = (
        pydantic.Field(default=None)
    )
    """
    <Warning>This property is in beta and is subject to change. It is provided for early access and testing purposes only.</Warning> custom user key/value pairs (key must be prefixed with "custom\_" and value must be "string" type)
    """

    custom_name: typing.Optional[str] = None
    custom_identifier: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...base_types.types.paginated_response import PaginatedResponse
import typing
from .status_data import StatusData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class StatusInfo(PaginatedResponse):
    """
    The status of an entity. This attribute is used to indicate details such as registration, operating, or liquidation status as well as an entity's license or sole proprietorship status.
    """

    data: typing.List[StatusData]
    next: typing.Optional[typing.Optional[typing.Any]] = None
    offset: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .environment import SayariEnvironment
import httpx
from .core.oauth_token_provider import OAuthTokenProvider
from .core.client_wrapper import SyncClientWrapper
from .attributes.client import AttributesClient
from .auth.client import AuthClient
from .entity.client import EntityClient
from .info.client import InfoClient
from .metadata.client import MetadataClient
from .notifications.client import NotificationsClient
from .project.client import ProjectClient
from .record.client import RecordClient
from .resolution.client import ResolutionClient
from .resource.client import ResourceClient
from .search.client import SearchClient
from .source.client import SourceClient
from .supply_chain.client import SupplyChainClient
from .trade.client import TradeClient
from .traversal.client import TraversalClient
from .core.client_wrapper import AsyncClientWrapper
from .attributes.client import AsyncAttributesClient
from .auth.client import AsyncAuthClient
from .entity.client import AsyncEntityClient
from .info.client import AsyncInfoClient
from .metadata.client import AsyncMetadataClient
from .notifications.client import AsyncNotificationsClient
from .project.client import AsyncProjectClient
from .record.client import AsyncRecordClient
from .resolution.client import AsyncResolutionClient
from .resource.client import AsyncResourceClient
from .search.client import AsyncSearchClient
from .source.client import AsyncSourceClient
from .supply_chain.client import AsyncSupplyChainClient
from .trade.client import AsyncTradeClient
from .traversal.client import AsyncTraversalClient


class BaseClient:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : SayariEnvironment
        The environment to use for requests from the client. from .environment import SayariEnvironment



        Defaults to SayariEnvironment.PRODUCTION



    client_id : str
    client_secret : str
    _token_getter_override : typing.Optional[typing.Callable[[], str]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from sayari import Sayari

    client = Sayari(
        client_id="YOUR_CLIENT_ID",
        client_secret="YOUR_CLIENT_SECRET",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: SayariEnvironment = SayariEnvironment.PRODUCTION,
        client_id: str,
        client_secret: str,
        _token_getter_override: typing.Optional[typing.Callable[[], str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        oauth_token_provider = OAuthTokenProvider(
            client_id=client_id,
            client_secret=client_secret,
            client_wrapper=SyncClientWrapper(
                base_url=_get_base_url(base_url=base_url, environment=environment),
                httpx_client=httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
                if follow_redirects is not None
                else httpx.Client(timeout=_defaulted_timeout),
                timeout=_defaulted_timeout,
            ),
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=_token_getter_override if _token_getter_override is not None else oauth_token_provider.get_token,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.attributes = AttributesClient(client_wrapper=self._client_wrapper)
        self.auth = AuthClient(client_wrapper=self._client_wrapper)
        self.entity = EntityClient(client_wrapper=self._client_wrapper)
        self.info = InfoClient(client_wrapper=self._client_wrapper)
        self.metadata = MetadataClient(client_wrapper=self._client_wrapper)
        self.notifications = NotificationsClient(client_wrapper=self._client_wrapper)
        self.project = ProjectClient(client_wrapper=self._client_wrapper)
        self.record = RecordClient(client_wrapper=self._client_wrapper)
        self.resolution = ResolutionClient(client_wrapper=self._client_wrapper)
        self.resource = ResourceClient(client_wrapper=self._client_wrapper)
        self.search = SearchClient(client_wrapper=self._client_wrapper)
        self.source = SourceClient(client_wrapper=self._client_wrapper)
        self.supply_chain = SupplyChainClient(client_wrapper=self._client_wrapper)
        self.trade = TradeClient(client_wrapper=self._client_wrapper)
        self.traversal = TraversalClient(client_wrapper=self._client_wrapper)


class AsyncBaseClient:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : SayariEnvironment
        The environment to use for requests from the client. from .environment import SayariEnvironment



        Defaults to SayariEnvironment.PRODUCTION



    client_id : str
    client_secret : str
    _token_getter_override : typing.Optional[typing.Callable[[], str]]
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from sayari import AsyncSayari

    client = AsyncSayari(
        client_id="YOUR_CLIENT_ID",
        client_secret="YOUR_CLIENT_SECRET",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: SayariEnvironment = SayariEnvironment.PRODUCTION,
        client_id: str,
        client_secret: str,
        _token_getter_override: typing.Optional[typing.Callable[[], str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        oauth_token_provider = OAuthTokenProvider(
            client_id=client_id,
            client_secret=client_secret,
            client_wrapper=SyncClientWrapper(
                base_url=_get_base_url(base_url=base_url, environment=environment),
                httpx_client=httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
                if follow_redirects is not None
                else httpx.Client(timeout=_defaulted_timeout),
                timeout=_defaulted_timeout,
            ),
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=_token_getter_override if _token_getter_override is not None else oauth_token_provider.get_token,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.attributes = AsyncAttributesClient(client_wrapper=self._client_wrapper)
        self.auth = AsyncAuthClient(client_wrapper=self._client_wrapper)
        self.entity = AsyncEntityClient(client_wrapper=self._client_wrapper)
        self.info = AsyncInfoClient(client_wrapper=self._client_wrapper)
        self.metadata = AsyncMetadataClient(client_wrapper=self._client_wrapper)
        self.notifications = AsyncNotificationsClient(client_wrapper=self._client_wrapper)
        self.project = AsyncProjectClient(client_wrapper=self._client_wrapper)
        self.record = AsyncRecordClient(client_wrapper=self._client_wrapper)
        self.resolution = AsyncResolutionClient(client_wrapper=self._client_wrapper)
        self.resource = AsyncResourceClient(client_wrapper=self._client_wrapper)
        self.search = AsyncSearchClient(client_wrapper=self._client_wrapper)
        self.source = AsyncSourceClient(client_wrapper=self._client_wrapper)
        self.supply_chain = AsyncSupplyChainClient(client_wrapper=self._client_wrapper)
        self.trade = AsyncTradeClient(client_wrapper=self._client_wrapper)
        self.traversal = AsyncTraversalClient(client_wrapper=self._client_wrapper)


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: SayariEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .source_id import SourceId
from ...generated_types.types.country import Country
from ...generated_types.types.entities import Entities
from ...generated_types.types.risk import Risk
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class FilterList(UniversalBaseModel):
    """
    Filter your search on the following attributes.
    """

    source: typing.Optional[typing.List[SourceId]] = None
    country: typing.Optional[typing.List[Country]] = None
    state: typing.Optional[typing.List[str]] = None
    city: typing.Optional[typing.List[str]] = None
    entity_type: typing.Optional[typing.List[Entities]] = None
    bounds: typing.Optional[typing.List[str]] = None
    risk: typing.Optional[typing.List[Risk]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...generated_types.types.entities import Entities
import typing
from ...shared_types.types.identifier import Identifier
from ...generated_types.types.country import Country
from .match_explanation import MatchExplanation
from .match_strength import MatchStrength
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ResolutionResult(UniversalBaseModel):
    profile: str
    score: float
    entity_id: str
    label: str
    type: Entities
    identifiers: typing.List[Identifier]
    psa_id: typing.Optional[float] = None
    addresses: typing.List[str]
    countries: typing.List[Country]
    sources: typing.List[str]
    typed_matched_queries: typing.List[str]
    matched_queries: typing.List[str]
    highlight: typing.Dict[str, typing.List[str]]
    explanation: typing.Dict[str, typing.List[MatchExplanation]]
    match_strength: MatchStrength

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...core.pydantic_utilities import UniversalBaseModel
import typing
from ...generated_types.types.relationships import Relationships
from .relationship_info import RelationshipInfo
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.pydantic_utilities import update_forward_refs


class RelationshipData(UniversalBaseModel):
    target: "EntityDetails"
    types: typing.Dict[Relationships, typing.List[RelationshipInfo]] = pydantic.Field()
    """
    Additional information for each [relationship type](/sayari-library/ontology/relationships).
    """

    dates: typing.List[str]
    first_observed: typing.Optional[str] = None
    former: typing.Optional[bool] = None
    last_observed: typing.Optional[str] = None
    start_date: typing.Optional[str] = None
    end_date: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .entity_details import EntityDetails  # noqa: E402
from .entity_relationships import EntityRelationships  # noqa: E402

update_forward_refs(EntityDetails, RelationshipData=RelationshipData)
update_forward_refs(EntityRelationships, RelationshipData=RelationshipData)
update_forward_refs(RelationshipData)



# This file was auto-generated by Fern from our API Definition.

from ...base_types.types.paginated_response import PaginatedResponse
import typing
from ...shared_types.types.record_details import RecordDetails
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class RecordSearchResponse(PaginatedResponse):
    """
    OK

    Examples
    --------
    from sayari.base_types import QualifiedCount
    from sayari.search import RecordSearchResponse
    from sayari.shared_types import RecordDetails

    RecordSearchResponse(
        offset=0,
        limit=1,
        size=QualifiedCount(
            count=182,
            qualifier="eq",
        ),
        next=True,
        data=[
            RecordDetails(
                id="a7e5a83df5551eb557688c84451abd9d/0000950123-09-004358-index.htm/1697610858173",
                label="Company Record from USA SEC 10-K Database",
                source="a7e5a83df5551eb557688c84451abd9d",
                publication_date="2009-03-10",
                acquisition_date="2023-10-18",
                references_count=10,
                record_url="/v1/record/a7e5a83df5551eb557688c84451abd9d%2F0000950123-09-004358-index.htm%2F1697610858173",
                source_url="https://www.sec.gov/Archives/edgar/data/2488/000119312513069422/0000950123-09-004358-index.htm",
                matches={
                    "text": [
                        "In\n    addition, David and <em>Victoria</em> <em>Beckham</em> have agreed to pursue the\n    development and exploitation of projects relating to\n    merchandising, products and skills (that do not, with certain\n    exceptions, include the name \x93<em>Beckham</em>\x94) exclusively\n    through a joint venture vehicle, <em>Beckham</em> Brand <em>Limited</em>",
                        "(\x93BBL\x94), which is owned one-third by each of David\n    <em>Beckham</em>, <em>Victoria</em> <em>Beckham</em>, and a subsidiary of 19 Entertainment.",
                        "For\n    example, 19 Entertainment manages <em>Victoria</em> <em>Beckham</em>, a fashion\n    and lifestyle personality as well as David <em>Beckham</em>, a globally\n    recognized soccer player who commenced playing for the Los\n    Angeles Galaxy of United States-based Major League Soccer in\n    July 2007 and is currently playing",
                        "<em>Beckham</em> (see\n    below under \x93<em>Beckham</em> Relationship\x94), Annie Lennox and\n    Cathy Dennis.",
                        "In 2008, <em>Victoria</em> successfully launched her\n    dress collection, a new denim collection under her DVB Style\n    brand and a DVB line of eyewear.",
                    ]
                },
                country="USA",
                page=8.0,
                page_count=92.0,
            )
        ],
    )
    """

    offset: int
    next: bool
    data: typing.List[RecordDetails]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .resolution_response_fields import ResolutionResponseFields
import typing
from .resolution_result import ResolutionResult
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ResolutionResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.resolution import (
        MatchExplanation,
        MatchStrength,
        ResolutionResponse,
        ResolutionResponseFields,
        ResolutionResult,
    )

    ResolutionResponse(
        fields=ResolutionResponseFields(
            name=["victoria beckham limited"],
        ),
        data=[
            ResolutionResult(
                profile="corporate",
                score=491.08936,
                entity_id="ds5rQ3rMIeoN3xZUzVyVNQ",
                label="VICTORIA BECKHAM",
                type="person",
                identifiers=[],
                addresses=[
                    "C/O LEE & THOMPSON LLP, 4 GEE'S COURT, ST-CHRISTOPHER'S PLACE"
                ],
                countries=["GBR", "MEX"],
                sources=["b9d809b02049993ba8dc2e4c5f7cceca"],
                typed_matched_queries=[
                    "name|0",
                    "name|100phrase|0",
                    "name|100match|0",
                    "looseName|0",
                ],
                matched_queries=["name"],
                highlight={"name": ["<em>VICTORIA</em> <em>BECKHAM</em>"]},
                explanation={
                    "name": [
                        MatchExplanation(
                            matched="<em>VICTORIA</em> <em>BECKHAM</em>",
                            uploaded="victoria beckham limited",
                            name_custom_tf_idf_score=0.5416772821044128,
                            high_quality_match_name=True,
                            is_deletion_recommended=False,
                            n_common_term_matches=1,
                            n_uncommon_term_matches=1,
                        )
                    ]
                },
                match_strength=MatchStrength(
                    value="weak",
                ),
            )
        ],
    )
    """

    fields: ResolutionResponseFields
    data: typing.List[ResolutionResult]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class UsageInfo(UniversalBaseModel):
    entity: typing.Optional[int] = None
    entity_summary: typing.Optional[int] = None
    record: typing.Optional[int] = None
    resolve: typing.Optional[int] = None
    search_entities: typing.Optional[int] = None
    search_records: typing.Optional[int] = None
    search_trade: typing.Optional[int] = None
    traversal: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import enum


class SayariEnvironment(enum.Enum):
    PRODUCTION = "https://api.sayari.com"
    DEV = "https://api.internal.sayari.com"



# This file was auto-generated by Fern from our API Definition.

import typing

Relationships = typing.Union[
    typing.Literal[
        "lawyer_of",
        "has_lawyer",
        "founder_of",
        "has_founder",
        "legal_predecessor_of",
        "has_legal_predecessor",
        "lawyer_in",
        "shipper_of",
        "shipped_by",
        "associate_of",
        "has_associate",
        "judicial_representative_of",
        "has_judicial_representative",
        "sole_proprietor_of",
        "has_sole_proprietor",
        "shareholder_of",
        "has_shareholder",
        "subsidiary_of",
        "has_subsidiary",
        "executive_of",
        "has_executive",
        "liquidator_of",
        "has_liquidator",
        "registered_agent_of",
        "has_registered_agent",
        "auditor_of",
        "has_auditor",
        "legal_representative_of",
        "has_legal_representative",
        "judidical_representative_of",
        "employee_of",
        "has_employee",
        "officer_of",
        "has_officer",
        "generic",
        "member_of_the_board_of",
        "has_member_of_the_board",
        "notify_party_of",
        "has_notify_party",
        "beneficial_owner_of",
        "has_beneficial_owner",
        "client_of",
        "has_client",
        "partner_of",
        "has_partner",
        "issuer_of",
        "has_issuer",
        "branch_of",
        "has_branch",
        "secretary_of",
        "has_secretary",
        "party_to",
        "has_party",
        "legal_successor_of",
        "has_legal_successor",
        "receiver_of",
        "received_by",
        "owner_of",
        "has_owner",
        "linked_to",
        "supervisor_of",
        "has_supervisor",
        "manager_of",
        "has_manager",
        "family_of",
        "carrier_of",
        "has_carrier",
        "ships_to",
        "receives_from",
        "director_of",
        "has_director",
        "possibly_same_as",
    ],
    typing.Any,
]
